.jBox-TooltipDark .jBox-container {
  border-radius: 4px;
  background: #000;
  color: #fff;
  box-shadow: 0 0 6px rgba(0, 0, 0, 0.4);
}

.jBox-TooltipDark .jBox-pointer:after {
  background: #000;
}

.jBox-TooltipDark .jBox-closeButton {
  background: #000;
}

.jBox-TooltipDark.jBox-closeButton-box:before {
  box-shadow: 0 0 6px rgba(0, 0, 0, 0.4);
}

.jBox-TooltipDark.jBox-closeButton-box .jBox-closeButton path {
  fill: #ddd;
}

.jBox-TooltipDark.jBox-closeButton-box .jBox-closeButton:hover path {
  fill: #fff;
}

.jBox-TooltipDark.jBox-closeButton-box .jBox-closeButton:active path {
  fill: #bbb;
}

/*# sourceMappingURL=jBox.TooltipDark.css.map */
