.jBox-TooltipBorder .jBox-container,
.jBox-TooltipBorder .jBox-pointer:after {
  border: 2px solid #49d;
}

.jBox-TooltipBorder .jBox-pointer:after {
  width: 22px;
  height: 22px;
}

.jBox-TooltipBorder .jBox-pointer-top,
.jBox-TooltipBorder .jBox-pointer-bottom {
  width: 34px;
  height: 13px;
}

.jBox-TooltipBorder .jBox-pointer-top:after,
.jBox-TooltipBorder .jBox-pointer-bottom:after {
  left: 6px;
}

.jBox-TooltipBorder .jBox-pointer-left,
.jBox-TooltipBorder .jBox-pointer-right {
  width: 13px;
  height: 34px;
}

.jBox-TooltipBorder .jBox-pointer-left:after,
.jBox-TooltipBorder .jBox-pointer-right:after {
  top: 6px;
}

.jBox-TooltipBorder.jBox-closeButton-box:before {
  width: 28px;
  height: 28px;
  background: #49d;
}

/*# sourceMappingURL=jBox.TooltipBorder.css.map */
