.jBox-TooltipBorderThick .jBox-container {
  box-shadow: none;
  border-radius: 8px;
  border: 4px solid #ccc;
}

.jBox-TooltipBorderThick .jBox-pointer:after {
  box-shadow: none;
  border: 4px solid #ccc;
  width: 24px;
  height: 24px;
}

.jBox-TooltipBorderThick .jBox-pointer-top,
.jBox-TooltipBorderThick .jBox-pointer-bottom {
  width: 38px;
  height: 13px;
}

.jBox-TooltipBorderThick .jBox-pointer-left,
.jBox-TooltipBorderThick .jBox-pointer-right {
  width: 13px;
  height: 38px;
}

.jBox-TooltipBorderThick.jBox-closeButton-box:before {
  width: 32px;
  height: 32px;
  background: #ccc;
}

/*# sourceMappingURL=jBox.TooltipBorderThick.css.map */
