.jBox-NoticeFancy .jBox-content,
.jBox-NoticeFancy .jBox-title {
  padding-left: 25px;
}

.jBox-NoticeFancy.jBox-Notice-color .jBox-container {
  color: #fff;
  background: #000;
}

.jBox-NoticeFancy.jBox-Notice-color .jBox-container:after {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  width: 8px;
  border-radius: 4px 0 0 4px;
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.4) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.4) 50%, rgba(255, 255, 255, 0.4) 75%, transparent 75%, transparent);
  background-size: 14px 14px;
}

.jBox-NoticeFancy.jBox-Notice-black .jBox-container:after,
.jBox-NoticeFancy.jBox-Notice-gray .jBox-container:after {
  background-color: #888;
}

.jBox-NoticeFancy.jBox-Notice-red .jBox-container:after {
  background-color: #e00;
}

.jBox-NoticeFancy.jBox-Notice-green .jBox-container:after {
  background-color: #6c0;
}

.jBox-NoticeFancy.jBox-Notice-blue .jBox-container:after {
  background-color: #49d;
}

.jBox-NoticeFancy.jBox-Notice-yellow .jBox-container:after {
  background-color: #fb0;
}

.jBox-NoticeFancy .jBox-countdown {
  left: 8px;
  border-radius: 0 4px 0 0;
}

/*# sourceMappingURL=jBox.NoticeFancy.css.map */
