// Box theme: TooltipSmall

.jBox-TooltipSmall {
  pointer-events: none;

  .jBox-container {
    border-radius: 2px;
  }

  .jBox-content {
    padding: 0 10px;
    line-height: 28px;
  }

  .jBox-pointer {
    &:after {
      width: 20px;
      height: 20px;
    }

    &-top,
    &-bottom {
      width: 22px;
      height: 8px;
    }

    &-right,
    &-left {
      width: 8px;
      height: 22px;
    }

    &-top:after {
      left: 1px;
      top: 6px;
    }

    &-right:after {
      top: 1px;
      right: 6px;
    }

    &-bottom:after {
      left: 1px;
      bottom: 6px;
    }

    &-left:after {
      top: 1px;
      left: 6px;
    }
  }
}
