<?php

declare(strict_types=1);

namespace App\Model;

use Contao\Model;

/**
 * add properties for IDE support
 *
 * @property string $hash
 */
class IsoProductMonthModel extends Model
{
    protected static $strTable = 'tl_iso_product_month';

}
