.jBox-TooltipSmallGray {
  pointer-events: none;
}

.jBox-TooltipSmallGray .jBox-container {
  font-size: 13px;
  line-height: 24px;
  border-radius: 12px;
  background-image: linear-gradient(to bottom, #fafafa, #f2f2f2);
}

.jBox-TooltipSmallGray .jBox-content {
  padding: 0 10px;
}

.jBox-TooltipSmallGray .jBox-pointer:after {
  width: 20px;
  height: 20px;
}

.jBox-TooltipSmallGray .jBox-pointer-top, .jBox-TooltipSmallGray .jBox-pointer-bottom {
  width: 22px;
  height: 8px;
}

.jBox-TooltipSmallGray .jBox-pointer-left, .jBox-TooltipSmallGray .jBox-pointer-right {
  width: 8px;
  height: 22px;
}

.jBox-TooltipSmallGray .jBox-pointer-top:after {
  background: #fafafa;
  left: 1px;
  top: 6px;
}

.jBox-TooltipSmallGray .jBox-pointer-right:after {
  top: 1px;
  right: 6px;
}

.jBox-TooltipSmallGray .jBox-pointer-bottom:after {
  background: #f2f2f2;
  left: 1px;
  bottom: 6px;
}

.jBox-TooltipSmallGray .jBox-pointer-left:after {
  top: 1px;
  left: 6px;
}

/*# sourceMappingURL=jBox.TooltipSmallGray.css.map */
