<?php

/**
 * TeamList for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_iso_product']['attr_monthyear'][0] = "Monat";
$GLOBALS['TL_LANG']['tl_iso_product']['attr_monthyear'][1] = "Der Monat, in dem die Veranstaltung statt findet.";
$GLOBALS['TL_LANG']['tl_iso_product']['not_buyable'][0] = "nicht online buchbar";
$GLOBALS['TL_LANG']['tl_iso_product']['not_buyable'][1] = "Diese Veranstaltung ist nicht online buchbar.";
$GLOBALS['TL_LANG']['tl_iso_product']['not_buyable_text'][0] = "Optional: Nicht buchbar Text";
$GLOBALS['TL_LANG']['tl_iso_product']['not_buyable_text'][1] = "Hier kann z.B. &quot;Ausgebucht&quot; als Zusatzinformation platziert werden.";
