.jBox-Notice {
  transition: margin .2s;
}

.jBox-Notice .jBox-container {
  border-radius: 4px;
  box-shadow: inset 1px 1px 0 0 rgba(255, 255, 255, 0.25), inset -1px -1px 0 0 rgba(0, 0, 0, 0.1);
}

.jBox-Notice .jBox-content {
  border-radius: 4px;
  padding: 12px 20px;
}

@media (max-width: 768px) {
  .jBox-Notice .jBox-content {
    padding: 10px 15px;
  }
}

@media (max-width: 500px) {
  .jBox-Notice .jBox-content {
    padding: 8px 10px;
  }
}

.jBox-Notice.jBox-hasTitle .jBox-content {
  padding-top: 5px;
}

@media (max-width: 500px) {
  .jBox-Notice.jBox-hasTitle .jBox-content {
    padding-top: 0;
  }
}

.jBox-Notice.jBox-hasTitle .jBox-title {
  padding: 12px 20px 0;
  font-weight: bold;
}

@media (max-width: 768px) {
  .jBox-Notice.jBox-hasTitle .jBox-title {
    padding: 10px 15px 0;
  }
}

@media (max-width: 500px) {
  .jBox-Notice.jBox-hasTitle .jBox-title {
    padding: 8px 10px 0;
  }
}

.jBox-Notice.jBox-closeButton-title .jBox-title {
  padding-right: 55px;
}

.jBox-Notice.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton {
  width: 40px;
}

.jBox-Notice.jBox-Notice-black .jBox-container {
  color: #fff;
  background: #000;
}

.jBox-Notice.jBox-Notice-black.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton path,
.jBox-Notice.jBox-Notice-black.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton:hover path {
  fill: #fff;
}

.jBox-Notice.jBox-Notice-gray .jBox-container {
  color: #222;
  background: #f6f6f6;
}

.jBox-Notice.jBox-Notice-gray.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton path,
.jBox-Notice.jBox-Notice-gray.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton:hover path {
  fill: #222;
}

.jBox-Notice.jBox-Notice-red .jBox-container {
  color: #fff;
  background: #d00;
}

.jBox-Notice.jBox-Notice-red.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton path,
.jBox-Notice.jBox-Notice-red.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton:hover path {
  fill: #fff;
}

.jBox-Notice.jBox-Notice-green .jBox-container {
  color: #fff;
  background: #5d0;
}

.jBox-Notice.jBox-Notice-green.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton path,
.jBox-Notice.jBox-Notice-green.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton:hover path {
  fill: #fff;
}

.jBox-Notice.jBox-Notice-blue .jBox-container {
  color: #fff;
  background: #49d;
}

.jBox-Notice.jBox-Notice-blue.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton path,
.jBox-Notice.jBox-Notice-blue.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton:hover path {
  fill: #fff;
}

.jBox-Notice.jBox-Notice-yellow .jBox-container {
  color: #000;
  background: #fd0;
}

.jBox-Notice.jBox-Notice-yellow.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton path,
.jBox-Notice.jBox-Notice-yellow.jBox-closeButton-title.jBox-hasTitle .jBox-closeButton:hover path {
  fill: #fff;
}

/*# sourceMappingURL=jBox.Notice.css.map */
