<?php

/**
 * Custom extension for Isotope for Contao
 *
 * Copyright (c) 2014 Benjamin Roth [http://www.esales-media.de]
 *
 * @package eSM_isotope_custom
 * @link    http://www.esales-media.de
 * @license commercial
 */

namespace App\Hooks;

use Contao\Controller;


class IsotopeHooks extends Controller
{
    public function addProductToCollection($objProduct, $intQuantity, $ProductCollection)
    {
        if ($objProduct->not_buyable)
        {
          return 0;
        }
        return $intQuantity;
    }

}
