.jBox-TooltipSmall {
  pointer-events: none;
}

.jBox-TooltipSmall .jBox-container {
  border-radius: 2px;
}

.jBox-TooltipSmall .jBox-content {
  padding: 0 10px;
  line-height: 28px;
}

.jBox-TooltipSmall .jBox-pointer:after {
  width: 20px;
  height: 20px;
}

.jBox-TooltipSmall .jBox-pointer-top, .jBox-TooltipSmall .jBox-pointer-bottom {
  width: 22px;
  height: 8px;
}

.jBox-TooltipSmall .jBox-pointer-right, .jBox-TooltipSmall .jBox-pointer-left {
  width: 8px;
  height: 22px;
}

.jBox-TooltipSmall .jBox-pointer-top:after {
  left: 1px;
  top: 6px;
}

.jBox-TooltipSmall .jBox-pointer-right:after {
  top: 1px;
  right: 6px;
}

.jBox-TooltipSmall .jBox-pointer-bottom:after {
  left: 1px;
  bottom: 6px;
}

.jBox-TooltipSmall .jBox-pointer-left:after {
  top: 1px;
  left: 6px;
}

/*# sourceMappingURL=jBox.TooltipSmall.css.map */
